@@ -388,7 +388,7 @@ static bool seekToNextHeaderToken(QIODevice *dev)
 /////////////////////////// KZip ///////////////////////////////////////
 ////////////////////////////////////////////////////////////////////////
 
-class KZip::KZipPrivate
+class Q_DECL_HIDDEN KZip::KZipPrivate
 {
 public:
     KZipPrivate()
@@ -1341,7 +1341,7 @@ KZip::ExtraField KZip::extraField() const
 ////////////////////////////////////////////////////////////////////////
 ////////////////////// KZipFileEntry////////////////////////////////////
 ////////////////////////////////////////////////////////////////////////
-class KZipFileEntry::KZipFileEntryPrivate
+class Q_DECL_HIDDEN KZipFileEntry::KZipFileEntryPrivate
 {
 public:
     KZipFileEntryPrivate()
@@ -1453,5 +1453,6 @@ QIODevice *KZipFileEntry::createDevice() const
     qCCritical(KArchiveLog) << "This zip file contains files compressed with method"
                 << encoding() << ", this method is currently not supported by KZip,"
                 << "please use a command-line tool to handle this file.";
+    delete limitedDev;
     return nullptr;
 }
